@@ -10,7 +10,7 @@ from lesscode.web.status_code import StatusCode
 def user_verification(username="admin", **kw):
     def wrapper(func):
         @functools.wraps(func)
-        async def run(self, *args, **kwargs):
+        def run(self, *args, **kwargs):
             if tornado.options.options.running_env != "local":
                 user_str = self.request.headers.get("User")
                 if user_str:
@@ -24,8 +24,23 @@ def user_verification(username="admin", **kw):
                 else:
                     raise BusinessException(StatusCode.ACCESS_DENIED)
 
-            return await func(self, *args, **kwargs)
+            return func(self, *args, **kwargs)
 
         return run
 
     return wrapper
+
+
+def login_verification(func):
+    @functools.wraps(func)
+    def wrapper(self, *args, **kwargs):
+        user = self.request.headers.get("User")
+        if not user:
+            raise BusinessException(StatusCode.INVALID_TOKEN)
+        else:
+            user_info = json.loads(user)
+            if not user_info:
+                raise BusinessException(StatusCode.INVALID_TOKEN)
+        return func(self, *args, **kwargs)
+
+    return wrapper
